# SLACplots

Common plotting utilities for plotting with matplotlib in the SLAC theme.  Colors are taken from the Stanford Identity Guide.  Other design choices are my own.

## Installation

This package is available on pypi!  To install, simply

```
pip install slacplots
```

## Examples

<img alt="plot" src="docs/example_plot.png" height="480" />
<img alt="histogram" src="docs/example_histogram.png" height="480" />

## Disclaimer

This is not an official publication of SLAC or Stanford University and is not intended to be used as a replacement for official Stanford guidelines for publications.